"""
RxNorm_get_related_drugs

List all related drug products (branded names, generic products, ingredient names) for a drug RXC...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def RxNorm_get_related_drugs(
    rxcui: Optional[str] = None,
    drug_name: Optional[str] = None,
    tty: Optional[str] = "IN+BN+SBD+SCD",
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    List all related drug products (branded names, generic products, ingredient names) for a drug RXC...

    Parameters
    ----------
    rxcui : str
        RxNorm Concept Unique Identifier. Use RxNorm_find_rxcui to resolve a drug name.
    drug_name : str
        Drug name to look up if RXCUI is not known.
    tty : str
        Space/plus-separated term types to include. Options: IN (ingredient), BN (bra...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v
        for k, v in {"rxcui": rxcui, "drug_name": drug_name, "tty": tty}.items()
        if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "RxNorm_get_related_drugs",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["RxNorm_get_related_drugs"]
